===========
wspr-varint
===========

.. image:: https://img.shields.io/pypi/v/wspr_varint.svg
        :target: https://pypi.python.org/pypi/wspr_varint

A variable length integer implementation for the wspr project.
